@@ -20,8 +20,7 @@ transparent_block! {
     pub use web_sys;
 
     pub use gxi_macro::gxi;
-    pub use gxi_parsers::{comp_new, comp_state};
-    pub use gxi_update_macro::update;
+    pub use gxi_parsers::*;
     pub use nodes::*;
     pub use should_render::*;
 
